TPI
===

|Tests| |Coverage| |Conda| |PyPI|

Python wrapper for `terraform-provider-iterative <https://github.com/iterative/terraform-provider-iterative>`_.


Installation
------------

- ``pip install tpi``


Contributions
-------------

Please do open issues & pull requests!

See
`CONTRIBUTING.md <https://github.com/iterative/tpi/tree/master/CONTRIBUTING.md>`_
for more guidance.

|Hits|

.. |Tests| image:: https://github.com/iterative/tpi/workflows/Test/badge.svg
   :target: https://github.com/iterative/tpi/actions
   :alt: Tests
.. |Coverage| image:: https://codecov.io/gh/iterative/tpi/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/iterative/tpi
   :alt: Coverage
.. |Conda| image:: https://img.shields.io/conda/v/conda-forge/tpi.svg?label=conda&logo=conda-forge
   :target: https://anaconda.org/conda-forge/tpi
   :alt: conda-forge
.. |PyPI| image:: https://img.shields.io/pypi/v/tpi.svg?label=pip&logo=PyPI&logoColor=white
   :target: https://pypi.org/project/tpi
   :alt: PyPI
.. |Hits| image:: https://caspersci.uk.to/cgi-bin/hits.cgi?q=tpi&style=social&r=https://github.com/iterative/tpi&a=hidden
   :target: https://caspersci.uk.to/cgi-bin/hits.cgi?q=tpi&a=plot&r=https://github.com/iterative/tpi&style=social
   :alt: Hits
